#!/bin/bash

# zonColor themes: Disable/enable backdrop (unfocused) window styling.
# To see changes, theme must be reloaded (or logout/login).

zcDR=$(dirname "$0"); zcFP=$(cd "$zcDR" && pwd); cd "$zcFP";

SystemThemesDir="$HOME/.themes";

Filename_Enable="menubar-border.css";
Filename_Disable="menubar-border_disabled.css";

FileList_Enable=$(find "$SystemThemesDir" -type f -path "*zoncolor*" -name "$Filename_Enable");
FileList_Disable=$(find "$SystemThemesDir" -type f -path "*zoncolor*" -name "$Filename_Disable");

String_Enable="Enable";
String_Disable="Disable";
SwitchChooseOpts=("$String_Enable" "$String_Disable");

SwitchChooseTitle="zonColor GTK Themes";
SwitchChooseHead="<big><b>Enable/disable menubar border for all zonColor GTK themes</b></big>";
SwitchChooseBody="<b>Please choose</b> (note: you may need to log out and log back in to see effect):";
SwitchChooseFoot="";
SwitchChooseString="$SwitchChooseHead\n\n$SwitchChooseBody$SwitchChooseFoot";
SwitchChooseWin="";
SwitchChooseExitcode="";

DoSwitch () {
	if (test "$1" = "$String_Enable"); then
		Filename_Source="$Filename_Disable";
		Filename_Target="$Filename_Enable";
	elif (test "$1" = "$String_Disable"); then
		Filename_Source="$Filename_Enable";
		Filename_Target="$Filename_Disable";
	fi;
	for FPFilename_Source in $(find "$SystemThemesDir" -type f -path "*zoncolor*" -name "$Filename_Source"); do
		FPFilename_Target=$(echo "$FPFilename_Source" | sed "s/$Filename_Source/$Filename_Target/g");
		mv -f "$FPFilename_Source" "$FPFilename_Target";
	done;
}

SwitchChoose () {
	SwitchChooseWin=$(zenity --height=200 \
		--title="$SwitchChooseTitle" --text="$SwitchChooseString" \
		--list --radiolist --hide-header --column="Pick" --column="To" \
		"FALSE" "${SwitchChooseOpts[0]}" "FALSE" "${SwitchChooseOpts[1]}" \
		2>/dev/null);
	SwitchChooseExitcode=$?;
	case $SwitchChooseExitcode in
		0) case $SwitchChooseWin in
			"${SwitchChooseOpts[0]}") DoSwitch "$String_Enable"; ;;
			"${SwitchChooseOpts[1]}") DoSwitch "$String_Disable"; ;;
			esac; ;;
		1)	echo -e "\nCancelled.\n"; ;;
	esac;
}

NoCssFilesErrorMsg () {
	NCFErrorMsgHead="Required CSS files not found.";
	NCFErrorMsgBody="Is zonColor GTK-themes installed?";
	NCFErrorMsgFoot="";
	NCFErrorMsgText=$(printf "$NCFErrorMsgHead\n$NCFErrorMsgBody\n$NCFErrorMsgFoot");
	echo "$NCFErrorMsgText";
	zenity --error --no-wrap --text="$NCFErrorMsgText" >/dev/null 2>&1;
}

if (command -v zenity >/dev/null 2>&1); then
	if ((! test -z "$FileList_Enable") || \
		(! test -z "$FileList_Disable")); then
		SwitchChoose;
	else
		NoCssFilesErrorMsg;
		exit 1;
	fi;
else
	echo "Unable to show options.";
	exit 1;
fi;

exit
